@@ -17,32 +17,12 @@
 //! You can create a style and use it with yew like this:
 //!
 //! ```rust
-//! use std::borrow::Cow;
-//!
 //! use yew::prelude::*;
-//! use stylist::css;
+//! use stylist::yew::styled_component;
 //!
-//! struct MyStyledComponent {}
-//!
-//! impl Component for MyStyledComponent {
-//!     type Message = ();
-//!     type Properties = ();
-//!
-//!     fn create(_: Self::Properties, _: ComponentLink<Self>) -> Self {
-//!         Self {}
-//!     }
-//!
-//!     fn change(&mut self, _: Self::Properties) -> ShouldRender {
-//!         false
-//!     }
-//!
-//!     fn update(&mut self, _: Self::Message) -> ShouldRender {
-//!         false
-//!     }
-//!
-//!     fn view(&self) -> Html {
-//!         html! {<div class=css!("color: red;")>{"Hello World!"}</div>}
-//!     }
+//! #[styled_component(MyStyledComponent)]
+//! fn my_styled_component() -> Html {
+//!     html! {<div class={css!("color: red;")}>{"Hello World!"}</div>}
 //! }
 //! ```
 //!
@@ -155,20 +135,18 @@
 //!
 //! ### Theming
 //!
-//! There're theming examples using
-//! [Yewdux](https://github.com/futursolo/stylist-rs/tree/master/examples/yew-theme-yewdux)
-//! and [yewtil::store](https://github.com/futursolo/stylist-rs/tree/master/examples/yew-theme-agent).
+//! There's theming example using
+//! [Yew Context API](https://github.com/futursolo/stylist-rs/tree/master/examples/yew-theme-context).
 //!
 //! ## Features Flags
 //!
 //! - `macros`: Enabled by default, this flag enables procedural macro support.
-//! - `random`: Enabled by default, this flag uses `rand` crate to generate a random
+//! - `random`: Enabled by default, this flag uses `fastrand` crate to generate a random
 //!   class name. Disabling this flag will opt for a class name that is counter-based.
 //! - `yew_integration`: This flag enables yew integration, which implements [`Classes`](::yew::html::Classes) for
 //!   [`Style`] and provides a [`Global`](yew::Global) component for applying global styles.
 
-#[cfg(target_arch = "wasm32")]
-#[path = "arch_wasm.rs"]
+#[cfg(any(feature = "yew_use_media_query", target_arch = "wasm32"))]
 mod arch;
 
 pub mod manager;
@@ -186,8 +164,8 @@ pub use style::Style;
 pub use style_src::StyleSource;
 pub use yield_style::YieldStyle;
 
-#[cfg_attr(documenting, doc(cfg(feature = "yew_integration")))]
-#[cfg(feature = "yew_integration")]
+#[cfg_attr(documenting, doc(cfg(feature = "yew")))]
+#[cfg(feature = "yew")]
 pub mod yew;
 
 #[cfg_attr(documenting, doc(cfg(feature = "macros")))]
@@ -237,8 +215,8 @@ pub use stylist_macros::global_style;
 /// use stylist::yew::Global;
 /// use yew::prelude::*;
 ///
-/// let rendered = html! {<div class=css!("color: red;") />};
-/// let rendered_global = html! {<Global css=css!("color: red;") />};
+/// let rendered = html! {<div class={css!("color: red;")} />};
+/// let rendered_global = html! {<Global css={css!("color: red;")} />};
 /// ```
 #[cfg_attr(documenting, doc(cfg(feature = "macros")))]
 #[cfg(feature = "macros")]
