@@ -1,4 +1,5 @@
-fn main() {
+#[test]
+fn test_nested_at_rule() {
     let _ = env_logger::builder().is_test(true).try_init();
     let dynamic_value = "blue";
     let style = stylist::style! {
