@@ -1,4 +1,5 @@
-fn main() {
+#[test]
+fn test_literal_at_support() {
     let style = stylist::style! {
         r#"@supports (display:grid) {
             background-color: grey;
